@@ -13,16 +13,16 @@ import os
 
 LOGS_DIR = 'logs'
 loglevel = 'INFO'
-bind = "0.0.0.0:9102"
+bind = "0.0.0.0:9103"
 #pidfile = "tmp/gunicorn.pid"
-APP = "wsgi"
+
 
 # 将stdout / stderr重定向到errorlog中的指定文件
 capture_output = True
-errorlog = "%s/gunicorn.log" % LOGS_DIR
-accesslog = errorlog
+#errorlog = "%s/gunicornd.log" % LOGS_DIR
+#accesslog = errorlog
 #通过启动脚本控制daemon模式,配合在supervisord监控
-daemon = True
+daemon = False
 workers = multiprocessing.cpu_count() + 1
 
 worker_class = 'sync'
